@@ -1,4 +1,4 @@
-// Copyright (C) 2003-2022 Free Software Foundation, Inc.
+// Copyright (C) 2003-2025 Free Software Foundation, Inc.
 //
 // This file is part of the GNU ISO C++ Library.  This library is free
 // software; you can redistribute it and/or modify it under the
@@ -25,33 +25,31 @@
 #include <testsuite_hooks.h>
 
 // libstdc++/12875
-void test01()
+void test02()
 {
   using namespace std;
 
-  const char* name = "tmp_setbuf4";
+  const char* name = "tmp_setbuf5";
   static char buf[1024];
   
-  FILE* out = fopen(name, "w");
-  fputs("Hello, world", out);
-  fclose(out);
+  filebuf out;
+  out.open(name, ios_base::out);
+  streamsize r = out.sputn("Hello,", 6);
+  VERIFY( r == 6 );
+  out.pubsetbuf(buf, 1024);
+  r = out.sputn(" world", 6);
+  VERIFY( r == 6 );
+  VERIFY( out.close() );
   
-  filebuf in;
-  in.open(name, ios_base::in);
+  FILE* in = fopen(name, "r");
   char str[256];
-  streamsize r = in.sgetn(str, 6);
-  VERIFY( r == 6 );
-  VERIFY( !memcmp(str, "Hello,", 6) );
-  in.pubsetbuf(buf, 1024);
-  r = in.sgetn(str, 6);
-  VERIFY( r == 6 );
-  VERIFY( !memcmp(str, " world", 6) );
-  in.close();
+  VERIFY( fgets(str, 256, in) );
+  VERIFY( !strcmp(str, "Hello, world") );
+  fclose(in);
 }
 
-// libstdc++/12875
 int main()
 {
-  test01();
+  test02();
   return 0;
 }
