@@ -1,6 +1,6 @@
-// 2006-07-15  Paolo Carlini  <pcarlini@suse.de>
+// 2006-10-12  Paolo Carlini  <pcarlini@suse.de>
 
-// Copyright (C) 2006-2021 Free Software Foundation, Inc.
+// Copyright (C) 2006-2025 Free Software Foundation, Inc.
 //
 // This file is part of the GNU ISO C++ Library.  This library is free
 // software; you can redistribute it and/or modify it under the
@@ -17,30 +17,32 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
+// { dg-options "-DWIDTH=500000" { target simulator } }
+
 // 27.6.2.5.4 basic_ostream character inserters
 
-// { dg-options "-DMAX_SIZE=50000" { target simulator } }
-
-#ifndef MAX_SIZE
-#define MAX_SIZE 5000000
-#endif
-
 #include <ostream>
 #include <sstream>
 #include <testsuite_hooks.h>
 
+#ifndef WIDTH
+#define WIDTH 50000000
+#endif
+
 // libstdc++/28277
 void test01()
 {
   using namespace std;
 
   wostringstream oss_01;
-  const string str_01(MAX_SIZE, 'a');
 
-  oss_01 << str_01.c_str();
+  oss_01.width(WIDTH);
+  const streamsize width = oss_01.width();
+
+  oss_01 << L'a';
 
   VERIFY( oss_01.good() );
-  VERIFY( oss_01.str().size() == str_01.size() );
+  VERIFY( oss_01.str().size() == wstring::size_type(width) );
 }
 
 int main()
