@@ -1,6 +1,6 @@
 // 2003-05-01 Petur Runolfsson <peturr02@ru.is>
 
-// Copyright (C) 2003-2022 Free Software Foundation, Inc.
+// Copyright (C) 2003-2025 Free Software Foundation, Inc.
 //
 // This file is part of the GNU ISO C++ Library.  This library is free
 // software; you can redistribute it and/or modify it under the
@@ -20,25 +20,27 @@
 #include <ext/stdio_sync_filebuf.h>
 #include <testsuite_hooks.h>
 
+// { dg-additional-files "cin_unget-1.txt" }
+
 // libstdc++/12048
-void test04()
+void test03()
 {
   const char* name = "cin_unget-1.txt";
 
   std::FILE* file = std::fopen(name, "r");
   __gnu_cxx::stdio_sync_filebuf<wchar_t> sbuf(file);
-  wchar_t buf[2];
-  VERIFY( sbuf.sgetn(buf, 2) == 2 );
+  std::wint_t c1 = sbuf.sbumpc();
+  VERIFY( c1 != WEOF );
   std::wint_t c2 = sbuf.sungetc();
   VERIFY( c2 != WEOF );
-  std::wint_t c3 = sbuf.sbumpc();
-  VERIFY( c3 == std::char_traits<wchar_t>::to_int_type(buf[1]) );
+  std::wint_t c3 = std::fgetwc(file);
+  VERIFY( c3 == c1 );
 
   std::fclose(file);
 }
 
 int main ()
 {
-  test04();
+  test03();
   return 0;
 }
